<?php

namespace Litecms\Products\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Products\Interfaces\ProductsRepositoryInterface;

class ProductsPublicController extends BaseController
{
    // use ProductsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Products\Interfaces\ProductsRepositoryInterface $products
     *
     * @return type
     */
    public function __construct(ProductsRepositoryInterface $products)
    {
        $this->repository = $products;
        parent::__construct();
    }

    /**
     * Show products's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $products = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$products::$products.names'))
            ->view('$products::public.products.index')
            ->data(compact('$products'))
            ->output();
    }

    /**
     * Show products's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $products = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$products::$products.names'))
            ->view('$products::public.products.index')
            ->data(compact('$products'))
            ->output();
    }

    /**
     * Show products.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $products = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$products->name . trans('$products::$products.name'))
            ->view('$products::public.products.show')
            ->data(compact('$products'))
            ->output();
    }

}
