<?php

namespace Litecms\Products\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Products\Models\Products;

class ProductsPolicy
{

    /**
     * Determine if the given user can view the products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function view(UserPolicy $user, Products $products)
    {
        if ($user->canDo('products.products.view') && $user->isAdmin()) {
            return true;
        }

        return $products->user_id == user_id() && $products->user_type == user_type();
    }

    /**
     * Determine if the given user can create a products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('products.products.create');
    }

    /**
     * Determine if the given user can update the given products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function update(UserPolicy $user, Products $products)
    {
        if ($user->canDo('products.products.edit') && $user->isAdmin()) {
            return true;
        }

        return $products->user_id == user_id() && $products->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Products $products)
    {
        return $products->user_id == user_id() && $products->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Products $products)
    {
        if ($user->canDo('products.products.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given products.
     *
     * @param UserPolicy $user
     * @param Products $products
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Products $products)
    {
        if ($user->canDo('products.products.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
